@@ -8,7 +8,7 @@ _PRCTL_SYSCALL = 157
 
 
 def prctl(option: int, arg2: int = 0, arg3: int = 0, arg4: int = 0, arg5: int = 0) -> int:
-    prctl = ctypes.CDLL(None).syscall  # type: ignore
+    prctl = ctypes.CDLL(None).syscall
     prctl.restype = ctypes.c_int
     prctl.argtypes = (
         ctypes.c_long,  # The actual syscall number
