@@ -331,7 +331,12 @@ class TransientVm:
         return None
 
     def __build_qemu_environment(self) -> Dict[str, str]:
-        env = {scan.SCAN_ENVIRON_SENTINEL: "1"}
+        env = {
+            # Always add the sentinel value
+            scan.SCAN_ENVIRON_SENTINEL: "1",
+            # Some versions of python don't propagate PATH, so always set it
+            "PATH": os.getenv("PATH") or "",
+        }
         data = {"name": self.name}
 
         if self.set_ssh_port is not None:
@@ -394,7 +399,7 @@ class TransientVm:
             logging.error("QEMU Process has died. Exiting")
             return self.__post_run(qemu_returncode)
 
-        sshfs_threads = []
+        sshfs_threads: List[checked_threading.Thread] = []
         for shared_spec in self.config.shared_folder:
             assert self.ssh_config is not None
             local, remote = shared_spec.split(":")
